@@ -98,12 +98,11 @@ psytkReadData = function( surveyOrDir , psytkAllowRepeatExp = TRUE , verbose = T
     colnames(listAnswers) = psytkListQuestions[,1]
     listScores            = listAnswers
 
-    setAnswers             = matrix( nrow = n , ncol=dim(psytkSetQuestions)[1] )
+    setAnswers             = matrix( nrow = n , ncol=dim(psytkSetQuestions)[1] ) # note, for set there are only answers (in survey file "a: <number>"
     colnames(setAnswers)   = psytkSetQuestions[,1]
-    setScores              = setAnswers
 
     version                = rep( NA , n ) # PsyToolkitversion used
-    test                   = rep( F , n )  # if survey was run as test, by default assume it is false
+    test                   = rep( FALSE , n )  # if survey was run as test, by default assume it is false
     startDate              = rep( NA , n ) 
     startTime              = rep( NA , n )
     startDateTime          = rep( NA , n ) # simply Date + Time for easier sorting
@@ -286,7 +285,7 @@ psytkReadData = function( surveyOrDir , psytkAllowRepeatExp = TRUE , verbose = T
     currentQuestionItemCounterA = 0
     currentQuestionItemCounterS = 0
 
-    if ( verbose  ){ catn("Now reading questionnaire data") }
+    if ( verbose  ){ message("Now reading questionnaire data") }
 
     includeItem = FALSE # this is a helper variable we set to TRUE
                         # when a new label is found but to FALSE if a
@@ -298,7 +297,7 @@ psytkReadData = function( surveyOrDir , psytkAllowRepeatExp = TRUE , verbose = T
 
         tmp = readLines( file.path( psytkSurveyFilesDir , psytkFiles[i] ))
 
-        if ( verbose ) { catn("\nStart reading data file:",psytkFiles[i]) }
+        if ( verbose ) { message("\nStart reading data file:",psytkFiles[i]) }
 
         for ( l in 1:length(tmp) ){ # new in 1.0.4
             line = tmp[l]
@@ -384,13 +383,13 @@ psytkReadData = function( surveyOrDir , psytkAllowRepeatExp = TRUE , verbose = T
                 if ( words[2] %in% surveyobject$overview[,1] ){
 
                     labelCounter = labelCounter + 1
-                    if ( labelCounter > 1 & currentType == "radio" ){
-                                        # cat("Answer was ",currentAnswer,"\n")
-                    }
+                    ## if ( labelCounter > 1 & currentType == "radio" ){
+                    ##                     # cat("Answer was ",currentAnswer,"\n")
+                    ## }
                     
                     ## Now the new label
                     currentLabel = words[2]
-                    if ( verbose  ){ catn("Found label",currentLabel) }
+                    if ( verbose  ){ message("Found label",currentLabel) }
 
                 }else{
 
@@ -403,20 +402,23 @@ psytkReadData = function( surveyOrDir , psytkAllowRepeatExp = TRUE , verbose = T
                     if ( l < length(tmp) ){
                         nextline = tmp[l+1]
                         if ( nextline == "t: set" ){ ## in this case, we need to add the variable to overview and to setAnswers
-                            surveyobject$overview = rbind( surveyobject$overview , c( words[2] , "set" , 1 , "from experiment") ) ## add at bottom of overview the new set question
+
+                            ## note for the rbind, the surveyobject$overview has 5 columns
+                            surveyobject$overview = rbind( surveyobject$overview , c( words[2] , "set" , 1 , "from experiment" , NA ) ) ## add at bottom of overview the new set question
+
                             newColnames = c( colnames( setAnswers ) , words[2] ) ## create for setAnswers a new set of columns with the new label
                             setAnswers = cbind( setAnswers , rep( NA , n ) ) ## add the variable to setAnswers, for starters it is empty
                             colnames(setAnswers)=newColnames ## set the colnames, this is important, because these are needed for setting the answer correctly
 
                             currentLabel = words[2]
-                            if ( verbose  ){ catn("Add label",currentLabel,"from experiments var out set") }
+                            if ( verbose  ){ message("Add label",currentLabel,"from experiments var out set") }
                         }else{
 
                             tmpWarning = paste("Label",words[2],"does not exist in survey.txt and this question item will be ignored. This is because of survey file:", psytkFiles[i],". This can happen if you changed your survey but you did not delete data. Or maybe the variable was generated by experiments.")
                             warnings = c(warnings,tmpWarning) 
                             
                             if ( verbose  ){
-                                catn(tmpWarning)
+                                message(tmpWarning)
                             }
                             
                             includeItem = FALSE # this makes that the code below can know that the label does not exist
@@ -520,7 +522,7 @@ psytkReadData = function( surveyOrDir , psytkAllowRepeatExp = TRUE , verbose = T
                 }
 
                 ## CHECK QUESTION #######################################
-                ## for check questions it is empty (F) or not (T)
+                ## for check questions it is empty (FALSE) or not (TRUE)
 
                 if ( currentType == "check" ){
                     ## check how many items this question has
@@ -596,7 +598,7 @@ psytkReadData = function( surveyOrDir , psytkAllowRepeatExp = TRUE , verbose = T
                 }
 
                 if ( currentType == "set" ){
-                    setScores[ i , currentLabel ] = as.numeric( currentAnswer )
+                    setAnswers[ i , currentLabel ] = as.numeric( currentAnswer )
                 }
                 if ( currentType == "radio" ){
                     radioScores[ i , currentLabel ] = as.numeric( currentAnswer )
@@ -640,7 +642,7 @@ psytkReadData = function( surveyOrDir , psytkAllowRepeatExp = TRUE , verbose = T
     radioAnswersOther = radioAnswersOther[, colSums(is.na(radioAnswersOther)) < nrow(radioAnswersOther), drop = FALSE] # drop=F keeps matrix even with one column
 
     ## Now we want to make sure scores are filled in with answers (because scores are not always set)
-    ## needed for: scaleScores, radioScores, dropScores, setScores
+    ## needed for: scaleScores, radioScores, dropScores
     ##
     ## in short, in radioScores (etc), you only have data for answers
     ## for which there was a specific scoring, so we need to fill up
@@ -649,7 +651,6 @@ psytkReadData = function( surveyOrDir , psytkAllowRepeatExp = TRUE , verbose = T
     tmpmask = is.na(radioScores) & !is.na(radioAnswers) ; scaleScores[ tmpmask ] = scaleAnswers[ tmpmask ]
     tmpmask = is.na(radioScores) & !is.na(radioAnswers) ; radioScores[ tmpmask ] = radioAnswers[ tmpmask ]
     tmpmask = is.na(dropScores)  & !is.na(dropAnswers)  ; dropScores[ tmpmask ]  = dropAnswers[ tmpmask ]
-    tmpmask = is.na(setScores)   & !is.na(setAnswers)   ; setScores[ tmpmask ]   = setAnswers[ tmpmask ]
 
     ## ##################################################################################################################
     ## Now we are done with scores and answers and can work on other stuff
@@ -684,7 +685,7 @@ psytkReadData = function( surveyOrDir , psytkAllowRepeatExp = TRUE , verbose = T
                 ## now check if there is a file with the assignments assignments_*.csv
                 expectedName = paste("assignments_",tmpId,".csv",sep="" )
                 if ( file.exists( file.path( psytkSurveyDir , expectedName ))){
-                    if(verbose(catn("Now reading CloudResearch demographic data file: ",file.path( psytkSurveyDir , expectedName ))))
+                    if(verbose(message("Now reading CloudResearch demographic data file: ",file.path( psytkSurveyDir , expectedName ))))
                     if ( is.null ( tmpCRData ) ){
                         tmpCRData = read.csv(file.path( psytkSurveyDir , expectedName ))
                     }else{
@@ -693,7 +694,7 @@ psytkReadData = function( surveyOrDir , psytkAllowRepeatExp = TRUE , verbose = T
                     }
                 }else{
                     if ( verbose ){
-                        catn("No demographics file(s) found. Given that you use CloudResearch, you could put it here in your data folder.")
+                        message("No demographics file(s) found. Given that you use CloudResearch, you could put it here in your data folder.")
                     }
                 }
             }
@@ -714,8 +715,8 @@ psytkReadData = function( surveyOrDir , psytkAllowRepeatExp = TRUE , verbose = T
     if ( all( c("PROLIFIC_PID","STUDY_ID","SESSION_ID") %in% names(cgi) ) ){
 
         if ( verbose  ){
-            catn("Data were collected with Prolific, now looking for Prolific demographic data.")
-            catn("If you don't have these, you can download them and put in your data folder here on your local computer.")
+            message("Data were collected with Prolific, now looking for Prolific demographic data.")
+            message("If you don't have these, you can download them and put in your data folder here on your local computer.")
         }
 
         ## if true, there should only be one projectId, but we accept that people might combine multiple studies here in one R analysis folder
@@ -736,7 +737,7 @@ psytkReadData = function( surveyOrDir , psytkAllowRepeatExp = TRUE , verbose = T
                 if ( file.exists( file.path( psytkSurveyDir , expectedName2 ))){ expectedName = expectedName2 }
 
                 if ( file.exists( file.path( psytkSurveyDir , expectedName ))){
-                    if(verbose(catn("Now reading Prolific demographic data file: ",file.path( psytkSurveyDir , expectedName ))))
+                    if(verbose(message("Now reading Prolific demographic data file: ",file.path( psytkSurveyDir , expectedName ))))
                     if ( is.null ( tmpPRData ) ){
                         tmpPRData = read.csv(file.path( psytkSurveyDir , expectedName ))
                     }else{
@@ -745,9 +746,9 @@ psytkReadData = function( surveyOrDir , psytkAllowRepeatExp = TRUE , verbose = T
                     }
                 }else{
                     if(verbose){
-                        catn("No demographics file(s) found. Given that you use Prolific, you could put it here in your data folder.")
-                        catn("The file should start with prolific_demographic_export_ or prolific_export_")
-                        catn("Maybe you have not downloaded it, don't need it, etc.")
+                        message("No demographics file(s) found. Given that you use Prolific, you could put it here in your data folder.")
+                        message("The file should start with prolific_demographic_export_ or prolific_export_")
+                        message("Maybe you have not downloaded it, don't need it, etc.")
                     }
                 }
             }
@@ -772,8 +773,7 @@ psytkReadData = function( surveyOrDir , psytkAllowRepeatExp = TRUE , verbose = T
         "scaleScores"      ,
         "checkAnswers"     , 
 
-        "setAnswers"       ,
-        "setScores"        ,
+        "setAnswers"       , # note that for set, there are only answers
 
         "listAnswers"      , 
 
@@ -831,11 +831,11 @@ psytkReadData = function( surveyOrDir , psytkAllowRepeatExp = TRUE , verbose = T
 
     psytkDuplicateExperiments = NULL
 
-    if ( verbose ){ hr(); catn("Now reading experiment data") ; hr() }
+    if ( verbose ){ hr(); message("Now reading experiment data") ; hr() }
 
     for ( expname in psytkExperiments ){
         
-        if( verbose ){ catn( "Now reading data for experiment",expname ) ; hr() }
+        if( verbose ){ message( "Now reading data for experiment",expname ) ; hr() }
 
         tmp=NULL ## will contain the experiment data frame
 
@@ -848,12 +848,12 @@ psytkReadData = function( surveyOrDir , psytkAllowRepeatExp = TRUE , verbose = T
                 tmpFilename = file.path( psytkExperimentDir , tmpFiles[1] ) ## take the first file name, we might allow to take second
             }else{
                 tmpWarning = paste("WARNING: No experiment file found for participant with ID",ID[i],"for experiment",expname,"\n")
-                if ( verbose ) { catn(tmpWarning) }
+                if ( verbose ) { message(tmpWarning) }
                 warnings = c( warnings , tmpWarning )
             }
 
             if ( length(tmpFiles)==1 | ( length(tmpFiles)>1 & psytkAllowRepeatExp ) ){
-                if ( verbose ){ catn("Now read in file: ",tmpFilename) }
+                if ( verbose ){ message("Now read in file: ",tmpFilename) }
                 tmptable = psytkReadTable( tmpFilename )
                 tmpData = data.frame( ID1=ID[i] , ID2 = IDcount[i] ,  tmptable )
                 tmp = psytkSaveRbind( tmp , tmpData ) ## also correctly combines non-matching dataframes
@@ -862,11 +862,11 @@ psytkReadData = function( surveyOrDir , psytkAllowRepeatExp = TRUE , verbose = T
             if ( length( tmpFiles ) > 1 ){
                 if ( psytkAllowRepeatExp ){
                     if ( verbose ) {
-                        catn("Participant:",ID[i],expname,"more than 1 file for same experiment, but you allowed with psytkAllowRepeatExp" )
+                        message("Participant:",ID[i],expname,"more than 1 file for same experiment, but you allowed with psytkAllowRepeatExp" )
                     }
                 }else{
                     if ( verbose ) {
-                        catn("Participant:",ID[i],expname,"more than 1 file for same experiment, but not used (psytkAllowRepeatExp is FALSE)" )
+                        message("Participant:",ID[i],expname,"more than 1 file for same experiment, but not used (psytkAllowRepeatExp is FALSE)" )
                     }
                 }
                 
@@ -879,18 +879,18 @@ psytkReadData = function( surveyOrDir , psytkAllowRepeatExp = TRUE , verbose = T
         rm(tmp)
     }
 
-    if ( verbose ) { cat("\n") } # new line to end progress of reading files
+    if ( verbose ) { message() } # new line to end progress of reading files
 
-    if ( verbose ) { catn( "All questionnaire and experiment data are read in" )}
+    if ( verbose ) { message( "All questionnaire and experiment data are read in" )}
 
     if ( !is.null(warnings) ){
-        hr()
-        catn("There were a number of warnings in reading in PsyToolkit data (separate from regular R warnings):")
-        for( i in 1:length(warnings) ){
-            catn( i , warnings[i] )
+        if ( verbose ){
+            message("There were a number of warnings in reading in PsyToolkit data (separate from regular R warnings):")
+            for( i in 1:length(warnings) ){
+                message( i , ": " , warnings[i] )
+            }
         }
-        hr()
     }
-
     return( returnList )
 }
+    
